==> haskell-math-functions-0.3.4.4-265-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-math-functions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 math-functions
version:              0.3.4.4
visibility:           public
id:                   math-functions-0.3.4.4-2b7QEe4Fl43AyGwC3ZszNp
key:                  math-functions-0.3.4.4-2b7QEe4Fl43AyGwC3ZszNp
license:              BSD-2-Clause
maintainer:           Alexey Khudyakov <alexey.skladnoy@gmail.com>
author:
    Bryan O'\''Sullivan <bos@serpentine.com>,
    Alexey Khudyakov <alexey.skladnoy@gmail.com>

homepage:             https://github.com/haskell/math-functions
synopsis:             Collection of tools for numeric computations
description:
    This library contain collection of various utilities for numerical
    computing. So far there'\''re special mathematical functions,
    compensated summation algorithm, summation of series, root finding
    for real functions, polynomial summation and Chebyshev
    polynomials.

category:             Math, Numeric
abi:                  473dd9a37be839d39bdecc272840f75b
exposed:              True
exposed-modules:
    Numeric.MathFunctions.Comparison Numeric.MathFunctions.Constants
    Numeric.Polynomial Numeric.Polynomial.Chebyshev Numeric.RootFinding
    Numeric.Series Numeric.SpecFunctions Numeric.SpecFunctions.Extra
    Numeric.SpecFunctions.Internal Numeric.Sum

hidden-modules:       Numeric.SpecFunctions.Compat
import-dirs:          /usr/lib/ghc-9.4.8/site-local/math-functions-0.3.4.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/math-functions-0.3.4.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/math-functions-0.3.4.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-math-functions
hs-libraries:         HSmath-functions-0.3.4.4-2b7QEe4Fl43AyGwC3ZszNp
depends:
    base-4.17.2.1 data-default-class-0.1.2.2-2EcHBs5cfSFLku8331ZnRi
    deepseq-1.4.8.0 primitive-0.9.1.0-Fzohuuo3yXQHgF9SkKDO4d
    vector-0.13.2.0-BnQJYTBpbJKJ2sldbPuyJj

haddock-interfaces:
    /usr/share/doc/haskell-math-functions/html/math-functions.haddock

haddock-html:         /usr/share/doc/haskell-math-functions/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-math-functions-0.3.4.4-269-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-math-functions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 math-functions
version:              0.3.4.4
visibility:           public
id:                   math-functions-0.3.4.4-FiRMA599lzm7ijpnshtXbj
key:                  math-functions-0.3.4.4-FiRMA599lzm7ijpnshtXbj
license:              BSD-2-Clause
maintainer:           Alexey Khudyakov <alexey.skladnoy@gmail.com>
author:
    Bryan O'\''Sullivan <bos@serpentine.com>,
    Alexey Khudyakov <alexey.skladnoy@gmail.com>

homepage:             https://github.com/haskell/math-functions
synopsis:             Collection of tools for numeric computations
description:
    This library contain collection of various utilities for numerical
    computing. So far there'\''re special mathematical functions,
    compensated summation algorithm, summation of series, root finding
    for real functions, polynomial summation and Chebyshev
    polynomials.

category:             Math, Numeric
abi:                  eb718adc029c7eb5c883b0a8dda04ee1
exposed:              True
exposed-modules:
    Numeric.MathFunctions.Comparison Numeric.MathFunctions.Constants
    Numeric.Polynomial Numeric.Polynomial.Chebyshev Numeric.RootFinding
    Numeric.Series Numeric.SpecFunctions Numeric.SpecFunctions.Extra
    Numeric.SpecFunctions.Internal Numeric.Sum

hidden-modules:       Numeric.SpecFunctions.Compat
import-dirs:          /usr/lib/ghc-9.4.8/site-local/math-functions-0.3.4.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/math-functions-0.3.4.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/math-functions-0.3.4.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-math-functions
hs-libraries:         HSmath-functions-0.3.4.4-FiRMA599lzm7ijpnshtXbj
depends:
    base-4.17.2.1 data-default-class-0.1.2.2-2EcHBs5cfSFLku8331ZnRi
    deepseq-1.4.8.0 primitive-0.9.1.0-F4HGYkgYEkOLs7asiZIPNd
    vector-0.13.2.0-7jLyylqham1Ij3AknS5IxU

haddock-interfaces:
    /usr/share/doc/haskell-math-functions/html/math-functions.haddock

haddock-html:         /usr/share/doc/haskell-math-functions/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
